@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2006-2012 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2006-2012,2016 -- leonerd@leonerd.org.uk
 
 package IPC::PerlSSH;
 
@@ -14,7 +14,9 @@ use IPC::Open2;
 
 use Carp;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
+
+our $READLEN = 256*1024; # 256KiB
 
 =head1 NAME
 
@@ -114,7 +116,9 @@ To work with remote IO handles, see the L<IPC::PerlSSH::Library::IO> module.
 
 =cut
 
-=head2 $ips = IPC::PerlSSH->new( Host => $host, ... )
+=head2 new (with Host)
+
+   $ips = IPC::PerlSSH->new( Host => $host, ... )
 
 Returns a new instance of a C<IPC::PerlSSH> object connected to the specified
 host. The following arguments can be specified:
@@ -148,7 +152,9 @@ C<ARRAY> reference
 
 =back
 
-=head2 $ips = IPC::PerlSSH->new( Command => \@command, ... )
+=head2 new (with Command)
+
+   $ips = IPC::PerlSSH->new( Command => \@command, ... )
 
 Returns a new instance of a C<IPC::PerlSSH> object which uses the STDIN/STDOUT
 streams of a command it executes, as the streams to communicate with the
@@ -172,13 +178,17 @@ fact running locally, but still in its own process.
 
  my $ips = IPC::PerlSSH->new( Command => $^X );
 
-=head2 $ips = IPC::PerlSSH->new( Readh => $rd, Writeh => $wr )
+=head2 new (with Readh + Writeh)
+
+   $ips = IPC::PerlSSH->new( Readh => $rd, Writeh => $wr )
 
 Returns a new instance of a C<IPC::PerlSSH> object using a given pair of
 filehandles to read from and write to the remote F<perl> process. It is
 allowable for both filehandles to be the same - for example using a socket.
 
-=head2 $ips = IPC::PerlSSH->new( Readfunc => \&read, Writefunc => \&write )
+=head2 new (with Readfunc + Writefunc)
+
+   $ips = IPC::PerlSSH->new( Readfunc => \&read, Writefunc => \&write )
 
 Returns a new instance of a C<IPC::PerlSSH> object using a given pair of
 functions as read and write operators.
@@ -257,7 +267,7 @@ sub read_message
 
    while( !defined $message ) {
       my $b;
-      $self->{readfunc}->( $b, 8192 ) or return ( "CLOSED" );
+      $self->{readfunc}->( $b, $READLEN ) or return ( "CLOSED" );
       $self->{readbuff} .= $b;
       ( $message, @args ) = $self->parse_message( $self->{readbuff} );
    }
@@ -269,7 +279,9 @@ sub read_message
 
 =cut
 
-=head2 @result = $ips->eval( $code, @args )
+=head2 eval
+
+   @result = $ips->eval( $code, @args )
 
 This method evaluates code in the remote host, passing arguments and returning
 the result.
@@ -313,9 +325,11 @@ sub eval
    }
 }
 
-=head2 $ips->store( $name, $code )
+=head2 store
 
-=head2 $ips->store( %funcs )
+   $ips->store( $name, $code )
+
+   $ips->store( %funcs )
 
 This method sends code to the remote host to store in named procedure(s) which
 can be executed later. The code should be passed in strings.
@@ -369,7 +383,9 @@ sub _has_stored_code
    return exists $self->{stored}{$name};
 }
 
-=head2 $ips->bind( $name, $code )
+=head2 bind
+
+   $ips->bind( $name, $code )
 
 This method is identical to the C<store> method, except that the remote
 function will be available as a plain function within the local perl
@@ -391,7 +407,9 @@ sub bind
    }
 }
 
-=head2 @result = $ips->call( $name, @args )
+=head2 call
+
+   @result = $ips->call( $name, @args )
 
 This method invokes a remote method that has earlier been defined using the
 C<store> or C<bind> methods. The arguments are passed and the result is
@@ -430,7 +448,9 @@ sub call
    }
 }
 
-=head2 $ips->use_library( $library, @funcs )
+=head2 use_library
+
+   $ips->use_library( $library, @funcs )
 
 This method loads a library of code from a module, and stores them to the
 remote perl by calling C<store> on each one. The C<$library> name may be a
