@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2008-2010 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2008-2010,2016 -- leonerd@leonerd.org.uk
 
 package IPC::PerlSSH::Library;
 
@@ -12,7 +12,7 @@ use Exporter 'import';
 our @EXPORT = qw( init func );
 use Carp;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 =head1 NAME
 
@@ -38,7 +38,7 @@ This can be loaded by
 
  my $ips = IPC::PerlSSH->new( Host => "over.there" );
 
- $ips->load_library( "Info" );
+ $ips->use_library( "Info" );
 
  print "Remote perl is running from " . $ips->call("perlbin") . "\n";
  print " Running on a machine of type " . $ips->call("ostype") .
@@ -93,7 +93,9 @@ my %package_funcs;
 
 =cut
 
-=head2 func( $name, $code )
+=head2 func
+
+   func( $name, $code )
 
 Declare a function called $name, which is implemented using the source code in
 $code. Note that $code must be a plain string, I<NOT> a CODE reference.
